@@ -4,7 +4,7 @@ use warnings;
 
 use Carp qw/carp croak/;
 use Test::Stream::State;
-use Test::Stream::Util qw/get_tid USE_THREADS USE_XS/;
+use Test::Stream::Util qw/get_tid/;
 
 use Scalar::Util qw/weaken/;
 
@@ -23,15 +23,6 @@ use Test::Stream::HashBase(
     }],
 );
 
-{
-    no warnings 'once';
-    *hid_pp = \&hid;
-
-    *get_todo = USE_XS('1.302004', 'get_todo_xs') || \&get_todo_pp;
-    no warnings 'redefine';
-    *hid = USE_XS('1.302004', 'hid_xs') || \&hid_pp;
-}
-
 my $ID_POSTFIX = 1;
 sub init {
     my $self = shift;
@@ -109,7 +100,7 @@ sub set_todo {
     return $ref;
 }
 
-sub get_todo_pp {
+sub get_todo {
     my $self = shift;
     my $array = $self->{+_TODO};
     pop @$array while @$array && !defined($array->[-1]);
@@ -148,7 +139,8 @@ sub unlisten {
         if $$ != $self->{+PID} || get_tid() != $self->{+TID};
 
     my %subs = map {$_ => $_} @_;
-    @{$self->{+_LISTENERS}} = grep { !$subs{$_} == $_ } @{$self->{+_LISTENERS}};
+
+    @{$self->{+_LISTENERS}} = grep { !$subs{$_} } @{$self->{+_LISTENERS}};
 }
 
 sub munge {
@@ -171,7 +163,7 @@ sub unmunge {
     carp "Useless removal of a munger in a child process or thread!"
         if $$ != $self->{+PID} || get_tid() != $self->{+TID};
     my %subs = map {$_ => $_} @_;
-    @{$self->{+_MUNGERS}} = grep { !$subs{$_} == $_ } @{$self->{+_MUNGERS}};
+    @{$self->{+_MUNGERS}} = grep { !$subs{$_} } @{$self->{+_MUNGERS}};
 }
 
 sub follow_up {
@@ -302,6 +294,11 @@ sub finalize {
             $_->($dbg, $self) for reverse @{$self->{+_FOLLOW_UPS}};
         }
 
+        # These need to be refreshed now
+        $plan   = $state->plan;
+        $count  = $state->count;
+        $failed = $state->failed;
+
         if (($plan && $plan eq 'NO PLAN') || ($do_plan && !$plan)) {
             $self->send(
                 Test::Stream::Event::Plan->new(
