@@ -47,7 +47,7 @@ sub _subtest {
     $hub->listen(sub { push @events => $_[1] });
     $hub->format(undef) if $buffered;
 
-    $hub->set_parent_todo($ctx->debug->todo);
+    $hub->set_parent_todo($ctx->debug->no_diag);
 
     my ($ok, $err, $finished);
     TS_SUBTEST_WRAPPER: {
